Module context

Module context 

DurableContext — the main context struct passed to handler functions.

Own the replay state machine, backend connection, and execution metadata. Provide methods for all durable operations to interact with the replay engine.

Structs

DurableContext
Main context for a durable execution invocation.